# Why Go Veg?
Why are people drawn to vegetarianism? Some just want to live longer, healthier lives. Others have made the switch to preserve Earth’s natural resources or from a love of animals and an ethical opposition to eating them.

Thanks to an abundance of scientific research that demonstrates the health and environmental benefits of a plant-based diet, even the federal government recommends that we consume most of our calories from grain products, vegetables and fruits.

And no wonder: An estimated 70 percent of all diseases, including one-third of all cancers, are related to diet. A vegetarian diet reduces the risk for chronic degenerative diseases such as obesity, coronary artery disease, high blood pressure, diabetes and certain types of cancer including colon, breast, prostate, stomach, lung and esophageal cancer.

Why go vegetarian? Chew on these reasons:

## You’ll ward off disease.
Vegetarian diets are more healthful than the average American diet, particularly in preventing, treating or reversing heart disease and reducing the risk of cancer. A low-fat vegetarian diet is the single most effective way to stop the progression of coronary artery disease or prevent it entirely. Cardiovascular disease kills 1 million Americans annually and is the leading cause of death in the United States.

But the mortality rate for cardiovascular disease is lower in vegetarians than in nonvegetarians, says Joel Fuhrman, MD, author of Eat to Live: The Revolutionary Formula for Fast and Sustained Weight Loss. A vegetarian diet is inherently healthful because vegetarians consume less animal fat and cholesterol (vegans consume no animal fat or cholesterol) and instead consume more fiber and more antioxidant-rich produce—another great reason to listen to Mom and eat your veggies!

## You’ll keep your weight down.
The standard American diet—high in saturated fats and processed foods and low in plant-based foods and complex carbohydrates—is making us fat and killing us slowly. According to the Centers for Disease Control and Prevention (CDC) and a division of the CDC, the National Center for Health Statistics, 64 percent of adults and 15 percent of children aged 6 to 19 are overweight and are at risk of weight-related ailments including heart disease, stroke and diabetes.

A study conducted from 1986 to 1992 by Dean Ornish, MD, president and director of the Preventive Medicine Research Institute in Sausalito, California, found that overweight people who followed a low-fat, vegetarian diet lost an average of 24 pounds in the first year and kept off that weight 5 years later. They lost the weight without counting calories or carbs and without measuring portions or feeling hungry.

## You’ll live longer.
If you switch from the standard American diet to a vegetarian diet, you can add about 13 healthy years to your life, says Michael F. Roizen, MD, author of The RealAge Diet: Make Yourself Younger with What You Eat. “People who consume saturated, four-legged fat have a shorter life span and more disability at the end of their lives. Animal products clog your arteries, zap your energy and slow down your immune system. Meat eaters also experience accelerated cognitive and sexual dysfunction at a younger age.”

## Want more proof of longevity?
Residents of Okinawa, Japan, have the longest life expectancy of any Japanese and likely the longest life expectancy of anyone in the world, according to a 30-year study of more than 600 Okinawan centenarians. Their secret: a low-calorie diet of unrefined complex carbohydrates, fiber-rich fruits and vegetables, and soy.

## You’ll build strong bones.
When there isn’t enough calcium in the bloodstream, our bodies will leach it from existing bone. The metabolic result is that our skeletons will become porous and lose strength over time. Most health care practitioners recommend that we increase our intake of calcium the way nature intended—through foods. Foods also supply other nutrients such as phosphorus, magnesium and vitamin D that are necessary for the body to absorb and use calcium.

People who are mildly lactose-intolerant can often enjoy small amounts of dairy products such as yogurt, cheese and lactose-free milk. But if you avoid dairy altogether, you can still get a healthful dose of calcium from dry beans, tofu, soymilk and dark green vegetables such as broccoli, kale, collards and turnip greens.

## You’ll reduce your risk of food-borne illnesses.
The CDC reports that food-borne illnesses of all kinds account for 76 million illnesses a year, resulting in 325,000 hospitalizations and 5,000 deaths in the United States. According to the US Food and Drug Administration (FDA), foods rich in protein such as meat, poultry, fish and seafood are frequently involved in food-borne illness outbreaks.

## You’ll ease the symptoms of menopause.
Many foods contain nutrients beneficial to perimenopausal and menopausal women. Certain foods are rich in phytoestrogens, the plant-based chemical compounds that mimic the behavior of estrogen. Since phytoestrogens can increase and decrease estrogen and progesterone levels, maintaining a balance of them in your diet helps ensure a more comfortable passage through menopause. Soy is by far the most abundant natural source of phytoestrogens, but these compounds also can be found in hundreds of other foods such as apples, beets, cherries, dates, garlic, olives, plums, raspberries, squash and yams. Because menopause is also associated with weight gain and a slowed metabolism, a low-fat, high-fiber vegetarian diet can help ward off extra pounds.

## You’ll have more energy.
Good nutrition generates more usable energy—energy to keep pace with the kids, tackle that home improvement project or have better sex more often, Michael F. Roizen, MD, says in The RealAge Diet. Too much fat in your bloodstream means that arteries won’t open properly and that your muscles won’t get enough oxygen.

The result? You feel zapped. Balanced vegetarian diets are naturally free of cholesterol-laden, artery-clogging animal products that physically slow us down and keep us hitting the snooze button morning after morning. And because whole grains, legumes, fruits and vegetables are so high in complex carbohydrates, they supply the body with plenty of energizing fuel.

## You’ll be more ‘regular.’
Eating a lot of vegetables necessarily means consuming more fiber, which pushes waste out of the body. Meat contains no fiber. People who eat lower on the food chain tend to have fewer instances of constipation, hemorrhoids and diverticulitis.

## You’ll help reduce pollution.
Some people become vegetarians after realizing the devastation that the meat industry is having on the environment. According to the US Environmental Protection Agency (EPA), chemical and animal waste runoff from factory farms is responsible for more than 173,000 miles of polluted rivers and streams. Runoff from farmlands is one of the greatest threats to water quality today. Agricultural activities that cause pollution include confined animal facilities, plowing, pesticide spraying, irrigation, fertilizing and harvesting.

## You’ll avoid toxic chemicals.
The EPA estimates that nearly 95 percent of the pesticide residue in the typical American diet comes from meat, fish and dairy products. Fish, in particular, contain carcinogens (PCBs, DDT) and heavy metals (mercury, arsenic, lead, cadmium) that can’t be removed through cooking or freezing.

Meat and dairy products can also be laced with steroids and hormones, so be sure to read the labels on the dairy products you purchase.

## You’ll help reduce famine.
About 70 percent of all grain produced in the United States is fed to animals raised for slaughter. The 7 billion livestock animals in the United States consume five times as much grain as is consumed directly by the American population. If all the grain currently fed to livestock were consumed directly by people, the number of people who could be fed would be nearly 800 million, says David Pimentel, professor of ecology at Cornell University. If the grain were exported, it would boost the US trade balance by $80 billion a year.

## You’ll spare animals.
Many vegetarians give up meat because of their concern for animals. Ten billion animals are slaughtered for human consumption each year. And, unlike the farms of yesteryear where animals roamed freely, today most animals are factory farmed: crammed into cages where they can barely move and fed a diet tainted with pesticides and antibiotics.

These animals spend their entire lives in crates or stalls so small that they can’t even turn around. Farmed animals are not protected from cruelty under the law—in fact, the majority of state anticruelty laws specifically exempt farm animals from basic humane protection.

## You’ll save money.
Meat accounts for 10 percent of Americans’ food spending. Eating vegetables, grains and fruits in place of the 200 pounds of beef, chicken and fish each nonvegetarian eats annually would cut individual food bills by an average of $4,000 a year.

## Your dinner plate will be full of color.
Disease-fighting phytochemicals give fruits and vegetables their rich, varied hues. They come in two main classes: carotenoids and anthocyanins. All rich yellow and orange fruits and vegetables—carrots, oranges, sweet potatoes, mangoes, pumpkins, corn—owe their color to carotenoids. Leafy green vegetables also are rich in carotenoids but get their green color from chlorophyll. Red, blue and purple fruits and vegetables—plums, cherries, red bell peppers—contain anthocyanins. Cooking by color is a good way to ensure youre eating a variety of naturally occurring substances that boost immunity and prevent a range of illnesses.

## Going vegetarian is a breeze.
It’s almost effortless these days to find great-tasting and good-for-you vegetarian foods, whether you’re strolling the aisles of your local supermarket or walking down the street at lunchtime. If you need inspiration in the kitchen, look no further than the internet, your favorite bookseller or your local vegetarian society’s newsletter for culinary tips and great recipes. And if you’re eating out, almost any ethnic restaurant will offer vegetarian selections. In a hurry? Most fast food and fast casual restaurants now include healthful and inventive salads, sandwiches and entrees on their menus. So rather than asking yourself why go vegetarian, the real question is: Why haven’t you gone vegetarian?
