# 10 ways vegetarianism can help save the planet
The average British carnivore eats more than 11,000 animals in their lifetime, each requiring vast amounts of land, fuel and water to reach the plate. It's time to think of waste as well as taste

If we really want to reduce the human impact on the environment, the simplest and cheapest thing anyone can do is to eat less meat. Behind most of the joints of beef or chicken on our plates is a phenomenally wasteful, land- and energy-hungry system of farming that devastates forests, pollutes oceans, rivers, seas and air, depends on oil and coal, and is significantly responsible for climate change. The way we breed animals is now recognised by the UN, scientists, economists and politicians as giving rise to many interlinked human and ecological problems, but with 1 billion people already not having enough to eat and 3 billion more mouths to feed within 50 years, the urgency to rethink our relationship with animals is extreme.

## 1 Overheating the planet
We humans eat about 230m tonnes of animals a year, twice as much as we did 30 years ago. We mostly breed four species – chickens, cows, sheep and pigs – all of which need vast amounts of food and water, emit methane and other greenhouse gases and produce mountains of physical waste.

But how much stress does our meat-eating put on ecological systems? The answer is a lot but the figures are imprecise and disputed. In 2006, the UN calculated that the combined climate change emissions of animals bred for their meat were about 18% of the global total – more than cars, planes and all other forms of transport put together.

The authors of the report, called Livestock's Long Shadow, did not just count the methane from the belching, farting cattle, but the gases released from the manures that they produce, the oil burned taking their carcasses to markets often thousands of miles away, the electricity needed to keep the meat cool, the gas used to cook it, the energy needed to plough and harvest the fields that grow the crops that the animals eat, even pumping the water that the cattle need.

The figure was revised upward in 2009 by two World Bank scientists to more than 51%, but attempts to fully account for meat-eating are condemned as simplistic. Should the studies have been based on giant US factory farms, or on more sustainable breeding in Europe? Should you include all the knock-on emissions from clearing forests? What about the fertiliser used to grow the crops to feed to the animals, or the emissions from the steel needed to build the boats that transport the cattle; or the "default" emissions – the greenhouse gases that would be released by substitute activities to grow food if we were to give up meat? And is it fair to count animals used for multiple purposes, as they mostly are in developing countries, from providing draught power to shoe leather or transport, and which only become meat once they reach the end of their economic lives?

It's an accounting nightmare but depending on how it's done, livestock's contribution to climate change can be calculated as low as 5-10% of global emissions or as high as 50%. Last year, a Food Climate Research Network report concluded that UK meat and dairy consumption was responsible for 8% of the country's total greenhouse gas emissions. But however it's counted, livestock farming ranks as one of the three greatest sources of climate changing emissions and one of the largest contributors to environmental degradation.

## 2 Eating up land
A human population expected to grow by 3 billion, a shift in developing countries to eating more meat, and global consumption on track to double in 40 years point to the mother of all food crises down the road. How much food we grow is not just limited by the amount of available land but meat-eaters need far more space than vegetarians. A Bangladeshi family living off rice, beans, vegetables and fruit may live on an acre of land or less, while the average American, who consumes around 270 pounds of meat a year, needs 20 times that.

Nearly 30% of the available ice-free surface area of the planet is now used by livestock, or for growing food for those animals. One billion people go hungry every day, but livestock now consumes the majority of the world's crops. A Cornell University study in 1997 found that around 13m hectares of land in the US were used to grow vegetables, rice, fruit, potatoes and beans, but 302m were used for livestock. The problem is that farm animals are inefficient converters of food to flesh. Broiler chickens are the best, needing around 3.4kg to produce 1kg of flesh, but pigs need 8.4kg for that kilo.

Other academics have calculated that if the grain fed to animals in western countries were consumed directly by people instead of animals, we could feed at least twice as many people – and possibly far more – as we do now.

To make matters worse, our hunger to eat animals has led to overstocking of fragile lands and massive soil erosion and desertification. Overgrazing, from the downlands of southern England to the uplands of Ethiopia and mountains of Nepal, causes great loss of fertility, as well as flooding.

But the figures must be treated with caution. Animal manures can revitalise the soil and millions of animals live on marginal land that is quite unsuitable for crops.

But before we leap to conclusions and lump all livestock rearing together, consider this: in western countries animals are bred and reared to put on as much meat as possible in the shortest time after which they are slaughtered. But in poorer regions, cattle – especially in dry areas – are central to human life and culture and often the only source of food and income for many millions of pastoralists. The ceaseless movement of these nomadic herders over vast areas is the backbone of many African economies and, a major new study from the International Institute for Environment and Development suggests, a far more ecologically efficient method of farming than the way cattle are reared in Australia or the US.

## 3 Drinking too much water
Eat a steak or a chicken and you are effectively consuming the water that the animal has needed to live and grow. Vegetarian author John Robbins calculates it takes 60, 108, 168, and 229 pounds of water to produce one pound of potatoes, wheat, maize and rice respectively. But a pound of beef needs around 9,000 litres – or more than 20,000lbs of water. Equally, it takes nearly 1,000 litres of water to produce one litre of milk. A broiler chicken, by contrast, is far more efficient, producing the same amount of meat as a cow on just 1,500 litres.

Pigs are some of the thirstiest animals. An average-sized north American pig farm with 80,000 pigs needs nearly 75m gallons of fresh water a year. A large one, which might have one million or more pigs, may need as much as a city.

Farming, which uses 70% of water available to humans, is already in direct competition for water with cities. But as demand for meat increases, so there will be less available for both crops and drinking. Rich but water-stressed countries such as Saudi Arabia, Libya, the Gulf states and South Africa say it makes sense to grow food in poorer countries to conserve their water resources, and are now buying or leasing millions of hectares of Ethiopia and elsewhere to provide their food. Every cow fattened in Gambella state in southern Ethiopia and exported to Abu Dhabi or Britain is taking the pressure off water supplies back home but increasing it elsewhere.

## 4 Causing deforestation
Global agribusiness has for 30 years turned to tropical rainforests – not for their timber but for the land that can be used to graze cattle or grow palm oil and soya. Millions of hectares of trees have been felled to provide burgers for the US and more recently animal feed for farms for Europe, China and Japan.

In its latest food report What's Feeding Our Food? Friends of the Earth estimates that around 6m hectares of forest land a year – an area equivalent to Latvia or twice the size of Belgium – and a similar acreage of peat and wetlands elsewhere, is converted to farmland a year. Of that, it says, most goes to livestock or to grow the crops to feed the cattle.

As soya becomes the world's major crop for chicken feed, so the industry is driving cattle ranching deeper into the forests.

## 5 Poisoning the earth
Industrial-scale agriculture now dominates the western livestock and poultry industries, and a single farm can now generate as much waste as a city. A cow excretes around 40kg of manure for every kilogram of edible beef it puts on and when you have many thousands crowded into a small area the effect can be dramatic. Their manure and urine is funnelled into massive waste lagoons sometimes holding as many as 40m gallons. These cesspools often break, leak or overflow, polluting underground water supplies and rivers with nitrogen, phosphorus and nitrates.

Tens of thousands of miles of rivers in the US, Europe and Asia are polluted each year. A single spill of millions of gallons of waste from a North Carolina pig factory lagoon in 1995 killed about 10 million fish and forced the closure of 364,000 acres of coastal wetlands to shellfishing.

The sheer quantity of animals now being raised for humans to eat now threatens the earth's biodiversity. More than one third of the world's 825 "ecoregions" identified by conservation group WWF are said to be threatened by livestock and giant US group Conservation International reckons that 23 out of 40-odd global "biodiversity hotspots" – the places considered most valuable for life – are now seriously affected by livestock production.

## 6 Spoiling the oceans
The present oil pollution disaster in the Gulf of Mexico is not the only problem that the region faces. Most summers between 13,000-20,000 sq km of sea at the mouth of the Mississippi become a "dead zone", caused when vast quantities of excess nutrients from animal waste, factory farms, sewage, nitrogen compounds and fertiliser are swept down the mighty river. This causes algal blooms which take up all the oxygen in the water to the point where little can live.

Nearly 400 dead zones ranging in size from one to over 70,000sq km have now been identified, from the Scandinavian fjords to the South China Sea. Animal farming is not the only culprit, but it is one of the worst.

## 7 Ruining the air
Anyone who has lived close to a large factory farm knows the smells can be extreme. Aside from greenhouse gases such as methane and carbon dioxide, cows and pigs produce many other polluting gases. Global figures are unavailable but in the US, livestock and animal feed crops are responsible for 37% of pesticide use, more than half of all the antibiotics manufactured and a third of the nitrogen and phosphorous in fresh water. Nearly two thirds of the manmade ammonia – a major contributor to acid rain – is also generated by livestock. In addition, concentrated factory farming of animals contributes to ozone pollution.

## 8 Making us prone to disease
Animal waste contains many pathogens including salmonella, E coli, cryptosporidium, and fecal coliform, which can transfer to humans through water run-off or manure or touch. In addition, millions of pounds of antibiotics is added to animal feed a year to speed the growth of cattle. But this contributes to the rise of resistant bacteria, and so makes it harder to treat human illnesses.

## 9 Draining the world's oil
The western animal farming economy is based on oil, which is why there were food riots in 23 countries when the oil price peaked in 2008. Every link in the chain of events that brings meat to the table demands electricity, from the production of the fertiliser put on the land to grow the animal feed, to pumping the water they need from the rivers or deep underground, to the fuel needed to transport the meat in giant refrigerated ships and the supermarket shelves. According to some studies, as much as one-third of all fossil fuels produced in the United States now go towards animal agriculture.

## 10 Meat's costly, in many ways
Polls suggest that 5-6% of the population eats no meat at all, with many millions of others consciously reducing the amount of meat they eat or only eating it occasionally. This is backed by new government figures which show that last year we ate 5% less meat by weight than in 2005.

But the quantities are still staggering: according to the Vegetarian Society, the average British carnivore eats over 11,000 animals in a lifetime: 1 goose, 1 rabbit, 4 cattle, 18 pigs, 23 sheep and lambs, 28 ducks, 39 turkeys, 1,158 chickens, 3,593 shellfish and 6,182 fish.

For this, say the vegetarians, the meat eaters get increased chances of obesity, cancers, heart diseases and other illnesses as well as a hole in the pocket. A meat diet is generally considered twice as expensive as a vegetarian one.
